triton.language.extra.cann.libdevice.sqrt_rz#
- triton.language.extra.cann.libdevice.sqrt_rz(arg0: None, _semantic: None = 'None')#
Computes the square root of x, rounded toward zero.
Example
import os # The libdevice SIMT ops below are A5-only (Ascend 910_95 / 950) and are # additionally gated by this env switch; set it so the examples run on A5 # hardware without extra configuration. os.environ.setdefault("TRITON_ENABLE_LIBDEVICE_SIMT", "1") import pytest import triton import triton.language as tl import triton.language.extra.cann.libdevice as libdevice import torch from triton.backends.ascend.utils import triton_enable_libdevice_simt _SIMT_SKIP_MSG = ("SIMT libdevice ops require an Ascend 950 target " "with TRITON_ENABLE_LIBDEVICE_SIMT=1; skipping.") @triton.jit def triton_kernel(input0, output, n_elements, XBLOCK: tl.constexpr, XBLOCK_SUB: tl.constexpr): offset = tl.program_id(0) * XBLOCK base = tl.arange(0, XBLOCK_SUB) loops: tl.constexpr = XBLOCK // XBLOCK_SUB for loop in range(loops): x0 = offset + (loop * XBLOCK_SUB) + base mask = x0 < n_elements tmp0 = tl.load(input0 + (x0), mask=mask) tmp1 = libdevice.sqrt_rz(tmp0) tl.store(output + (x0), tmp1, mask=mask) @pytest.mark.skipif(not triton_enable_libdevice_simt(), reason=_SIMT_SKIP_MSG) def test_sqrt_rz(): x0 = (torch.rand((8, )) + 0.1).to(torch.float32).npu() expected = (torch.sqrt(x0)).to(torch.float32).npu() output = torch.empty(8, dtype=torch.float32, device='npu') triton_kernel[(1, )](x0, output, 8, XBLOCK=8, XBLOCK_SUB=8, force_simt_only=True) torch.testing.assert_close(output, expected, rtol=1e-02, atol=1e-02, equal_nan=True) if __name__ == "__main__": if not triton_enable_libdevice_simt(): print(_SIMT_SKIP_MSG) else: test_sqrt_rz()
Special Restrictions
x:
float32
Return value:
tl.tensor, returns the square root of x.Return type:
float32Compilation modes: SIMT